@@ -8,6 +8,7 @@ from .docker_build import docker_build_and_start, docker_stop
 from .django_user_model import add_custom_user_from_docker
 from .urls_setup import change_project_urls
 from .format_code import format_with_black
+from .copy_assets import copy_assets_to_current_dir
 
 
 def destroy_setup():
@@ -29,7 +30,7 @@ def greet():
     print("\n\n■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■")
     print("■■■  Hybrid Django React Starter Project  ■■")
     print("■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■")
-    print("\n\n## Setting up project structure ##\n")
+    print("\n\n■■ Setting up project structure ■■\n")
 
 
 def main():
@@ -37,6 +38,9 @@ def main():
     greet()
     print("\n  ■ Please introduce the project's metadata\n")
     config = get_user_config()
+    
+    print("\n  ■ Copying assets\n")
+    copy_assets_to_current_dir()
 
     print("\n  ■ Setting up poetry\n")
     setup_poetry(config)
@@ -44,12 +48,12 @@ def main():
     print("\n  ■ Setting up pytest\n")
     setup_pytest(config)
     
-    print("\n  ■ Creating Django project\n")
-    create_django_project(config)
-
     print("\n  ■ Initializing Docker container\n")
     docker_build_and_start()
 
+    print("\n  ■ Creating Django project\n")
+    create_django_project(config)
+
     print("\n  ■ Creating custom User in Django app 'users'\n")
     add_custom_user_from_docker(config)
 
@@ -59,12 +63,19 @@ def main():
     print("\n  ■ Formatting python files\n")
     format_with_black()
 
-    # print("\n  ■ Stopping Docker container\n")
-    # docker_stop()
+    print("\n  ■ Stopping Docker container\n")
+    docker_stop()
     
-    # print("\n  ■ Finishing...\n")
+    print("\n  ■ Finishing...\n")
     # destroy_setup()
 
+    print("\n\n■■ Finished! Your Django React project is set up! ■■\n")
+
+    print("\n\n■ To start working, spin up your container with the command 'docker-compose up -d'\n")
+
+    print("\n\n■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■")
+    print("■■■  Thank you for using this Hybrid Django React Starter Project, bye!  ■■")
+    print("■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■")
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
